Android Activity integration
Provides the main entry point for Android applications and handles the Android activity lifecycle events.
Functions
- android_
main - Placeholder for non-Android builds (allows cross-compilation checks)
Android Activity integration
Provides the main entry point for Android applications and handles the Android activity lifecycle events.